@@ -20,43 +20,35 @@
  */
 
 #include "rhighlighter.h"
+#include "rkeywords.h"
 
 #include <QTextEdit>
 #include <QDebug>
 
-const QStringList RHighlighter::keywords_list=QStringList()
-    << QLatin1String("if") << QLatin1String("else") << QLatin1String("switch") << QLatin1String("while") << QLatin1String("for") << QLatin1String("repeat") << QLatin1String("function") << QLatin1String("in")
-    << QLatin1String("next") << QLatin1String("break") << QLatin1String("TRUE") << QLatin1String("FALSE") << QLatin1String("NULL") << QLatin1String("NA") << QLatin1String("NA_integer_") << QLatin1String("NA_real_")
-    << QLatin1String("NA_complex_") << QLatin1String("NA_character_") << QLatin1String("Inf") << QLatin1String("NaN");
-
 const QStringList RHighlighter::operators_list=QStringList()
-   << QLatin1String("(\\+|\\-|\\*|/|<-|->|<=|>=|={1,2}|\\!=|\\|{1,2}|&{1,2}|:{1,3}|\\^|@|\\$|~)((?!(\\+|\\-|\\*|/|<-|->|<=|>=|=|\\!=|\\||&|:|\\^|@|\\$|~))|$)")
-   << QLatin1String("%[^%]*%"); // Taken in Kate highlighter
+   << QLatin1String("(\\+|\\-|\*{1,2}|/|&lt;=?|&gt;=?|={1,2}|\\!=?|\|{1,2}|&amp;{1,2}|:{1,3}|\^|@|\\$|~)")
+   << QLatin1String("%[^%]*%"); // Taken in r.xml syntax file from KSyntaxHighlighter
 
 const QStringList RHighlighter::specials_list=QStringList()
     << QLatin1String("BUG") << QLatin1String("TODO") << QLatin1String("FIXME") << QLatin1String("NB") << QLatin1String("WARNING") << QLatin1String("ERROR");
 
 RHighlighter::RHighlighter(QObject* parent) : Cantor::DefaultHighlighter(parent)
 {
-    foreach (const QString& s, keywords_list)
-        keywords.append(QRegExp(QLatin1String("\\b")+s+QLatin1String("\\b")));
+    addKeywords(RKeywords::instance()->keywords());
+
     foreach (const QString& s, operators_list)
         operators.append(QRegExp(s));
     foreach (const QString& s, specials_list)
         specials.append(QRegExp(QLatin1String("\\b")+s+QLatin1String("\\b")));
 }
 
-RHighlighter::~RHighlighter()
-{
-}
-
 void RHighlighter::refreshSyntaxRegExps()
 {
     emit syntaxRegExps(variables,functions);
 }
 
-// FIXME: due to lack of lookbehinds in QRegExp here we use a flag showing if we need to shift the boundary of formating
-// to make up for the accidently matched character
+// FIXME: due to lack of lookbehinds in QRegExp here we use a flag showing if we need to shift the boundary of formatting
+// to make up for the accidentally matched character
 void RHighlighter::formatRule(const QRegExp &p, const QTextCharFormat &fmt, const QString& text,bool shift)
 {
     int index = p.indexIn(text);
@@ -86,11 +78,15 @@ void RHighlighter::highlightBlock(const QString& text)
     // TODO: find more elegant solution not involving double formatting
     formatRule(QRegExp(QLatin1String("\\b[A-Za-z0-9_]+(?=\\()")),errorFormat(),text);
 
-    //formatRule(QRegExp("[^A-Za-z_]-?([0-9]+)?(((e|i)?-?)|\\.)[0-9]*L?"),numberFormat(),text,true); // TODO: errorneous number formats, refine
-    massFormat(keywords,keywordFormat(),text);
+    //formatRule(QRegExp("[^A-Za-z_]-?([0-9]+)?(((e|i)?-?)|\\.)[0-9]*L?"),numberFormat(),text,true); // TODO: erroneous number formats, refine
     massFormat(operators,operatorFormat(),text);
-    massFormat(specials,commentFormat(),text); // FIXME must be distinc
+    massFormat(specials,commentFormat(),text); // FIXME must be distinct
     massFormat(functions,functionFormat(),text);
     massFormat(variables,variableFormat(),text);
     formatRule(QRegExp(QLatin1String("\"[^\"]+\"")),stringFormat(),text); // WARNING a bit redundant
 }
+
+void RHighlighter::updateHighlighting()
+{
+    emit rulesChanged();
+}
