@@ -34,15 +34,16 @@ LuaBackend::LuaBackend( QObject* parent,const QList<QVariant> args ) : Cantor::B
     new LuaScriptExtension(this);
 }
 
-LuaBackend::~LuaBackend()
-{
-}
-
 QString LuaBackend::id() const
 {
     return QLatin1String("lua");
 }
 
+QString LuaBackend::version() const
+{
+    return QLatin1String("LuaJIT 2.0");
+}
+
 Cantor::Session* LuaBackend::createSession()
 {
     return new LuaSession(this);
