@@ -41,10 +41,6 @@ LatexEntry::LatexEntry(Worksheet* worksheet) : WorksheetEntry(worksheet), m_text
     connect(m_textItem, &WorksheetTextItem::doubleClick, this, &LatexEntry::resolveImagesAtCursor);
 }
 
-LatexEntry::~LatexEntry()
-{
-}
-
 void LatexEntry::populateMenu(QMenu* menu, QPointF pos)
 {
     bool imageSelected = false;
@@ -132,6 +128,7 @@ void LatexEntry::setContent(const QDomElement& content, const KZip& file)
             format.setProperty(EpsRenderer::ImagePath, imagePath);
             format.setProperty(EpsRenderer::Code, latexCode);
             cursor.insertText(QString(QChar::ObjectReplacementCharacter), format);
+            m_textItem->denyEditing();
         } else
         {
             cursor.insertText(latexCode);
@@ -144,8 +141,6 @@ void LatexEntry::setContent(const QDomElement& content, const KZip& file)
 
 QDomElement LatexEntry::toXml(QDomDocument& doc, KZip* archive)
 {
-    Q_UNUSED(archive);
-
     QDomElement el = doc.createElement(QLatin1String("Latex"));
     el.appendChild( doc.createTextNode( latexCode() ));
 
@@ -164,7 +159,7 @@ QDomElement LatexEntry::toXml(QDomDocument& doc, KZip* archive)
             isEpsFileExists = QFile::exists(fileName);
             }
 
-        if (isEpsFileExists)
+        if (isEpsFileExists && archive)
             {
             const QUrl& url=QUrl::fromLocalFile(fileName);
             archive->addLocalFile(url.toLocalFile(), url.fileName());
@@ -239,6 +234,7 @@ void LatexEntry::resolveImagesAtCursor()
         cursor.movePosition(QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
 
     cursor.insertText(m_textItem->resolveImages(cursor));
+    m_textItem->allowEditing();
 }
 
 QString LatexEntry::latexCode()
@@ -363,6 +359,7 @@ bool LatexEntry::renderLatexCode()
         cursor.movePosition(QTextCursor::Start);
         cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
         cursor.insertText(QString(QChar::ObjectReplacementCharacter), formulaFormat);
+        m_textItem->denyEditing();
     }
     delete renderer;
     return success;
