@@ -23,7 +23,7 @@
 
 #include <KCompletion>
 
-#include <cantor_export.h>
+#include "cantor_export.h"
 
 namespace Cantor
 {
